from setuptools import setup, find_packages

setup(
name="fredmathy",
version="0.1.1",
description="A simple Python package for math operations and geometry calculations",
packages=find_packages(),
classifiers=[
"Programming Language :: Python :: 3",
"License :: OSI Approved :: MIT License",
"Operating System :: OS Independent",
],
python_requires=">=3.6",
)